@@ -1,6 +1,6 @@
 
 /* GnomeMeeting -- A Video-Conferencing application
- * Copyright (C) 2000-2001 Damien Sandras
+ * Copyright (C) 2000-2003 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,32 +15,42 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *
+ * GnomeMeting is licensed under the GPL license and as a special exception,
+ * you have permission to link or otherwise combine this program with the
+ * programs OpenH323 and Pwlib, and distribute the combination, without
+ * applying the requirements of the GNU GPL to the OpenH323 program, as long
+ * as you do follow the requirements of the GNU GPL for all the rest of the
+ * software thus combined.
  */
 
-/*                         preferences.h
- *                       -------------------
+
+/*
+ *                         pref_window.h  -  description
+ *                         -----------------------------
  *   begin                : Tue Dec 26 2000
- *   copyright            : (C) 2000-2001 by Damien Sandras
- *   description          : This file contains all functions needed to create
- *                          the preferences window and all its callbacks
- *   email                : dsandras@seconix.com
+ *   copyright            : (C) 2000-2003 by Damien Sandras
+ *   description          : This file contains all the functions needed to
+ *                          create the preferences window and all its callbacks
+ *   Additional code      : Miguel Rodrguez Prez  <migrax@terra.es> 
  */
 
+
 #ifndef _PREFERENCES_H_
 #define _PREFERENCES_H_
 
-#include <gtk/gtk.h>
-
 #include "common.h"
 
 
 /* DESCRIPTION  :  /
  * BEHAVIOR     :  It builds the preferences window
  *                 (sections' ctree / Notebook pages) and connect GTK signals
- *                 to appropriate callbacks
+ *                 to appropriate callbacks, then returns it.
  * PRE          :  /
  */
-void gnomemeeting_init_pref_window ();
+GtkWidget *
+gnomemeeting_pref_window_new (GmPrefWindow *);
 
 
 /* DESCRIPTION  :  / 
